@@ -6,12 +6,12 @@ import (
 
 	"github.com/spf13/cobra"
 
-	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/gql"
 	"github.com/superfly/flyctl/iostreams"
 
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/render"
 )
 
@@ -36,7 +36,7 @@ func newList() (cmd *cobra.Command) {
 func runList(ctx context.Context) (err error) {
 	var (
 		out    = iostreams.FromContext(ctx).Out
-		client = fly.ClientFromContext(ctx).GenqClient
+		client = flyutil.ClientFromContext(ctx).GenqClient()
 	)
 
 	response, err := gql.ListAddOns(ctx, client, "upstash_redis")
@@ -45,7 +45,7 @@ func runList(ctx context.Context) (err error) {
 
 	for _, addon := range response.AddOns.Nodes {
 		options, _ := addon.Options.(map[string]interface{})
-		var eviction = "Disabled"
+		eviction := "Disabled"
 
 		if options["eviction"] != nil && options["eviction"].(bool) {
 			eviction = "Enabled"
